Class: OpenApiSDK::Models::Operations::AccessLevel

Inherits:
T::Enum
  • Object
show all
Defined in:
lib/open_api_sdk/models/operations/accesslevel.rb

Overview

AccessLevel - The workspace-level access level settings for the folder. Default is write which allows full access to the folder for all team members. The other options are read (view-only access) and null (no access) and are only available on Business plans and above.