Class: OpenApiSDK::Models::Operations::Status

Inherits:
T::Enum
  • Object
show all
Defined in:
lib/open_api_sdk/models/operations/status.rb

Overview

Status - Useful for marking a commission as pending, refunded, duplicate, canceled, or fraudulent. Takes precedence over ‘saleAmount` and `modifySaleAmount`. When a commission is marked as pending, refunded, duplicate, canceled, or fraudulent, it will be omitted from the payout, and the payout amount will be recalculated accordingly. Paid commissions cannot be updated.