Exception: OpenApiSDK::Models::Errors::Forbidden

Inherits:
StandardError
  • Object
show all
Extended by:
T::Sig
Includes:
Crystalline::MetadataFields
Defined in:
lib/open_api_sdk/models/errors/forbidden.rb

Overview

The client does not have access rights to the content; that is, it is unauthorized, so the server is refusing to give the requested resource. Unlike 401 Unauthorized, the client’s identity is known to the server.

Instance Method Summary collapse

Methods included from Crystalline::MetadataFields

#field, #fields, included, #marshal_single, #to_dict, #to_json

Constructor Details

#initialize(error:) ⇒ Forbidden

Returns a new instance of Forbidden.



19
20
21
# File 'lib/open_api_sdk/models/errors/forbidden.rb', line 19

def initialize(error:)
  @error = error
end

Instance Method Details

#==(other) ⇒ Object



24
25
26
27
28
# File 'lib/open_api_sdk/models/errors/forbidden.rb', line 24

def ==(other)
  return false unless other.is_a? self.class
  return false unless @error == other.error
  true
end